#!/bin/sh

# https://github.com/pbek/QOwnNotes/

git clone https://github.com/qownnotes/md4c src/libraries/md4c
rm -rf src/libraries/md4c/.*

git clone https://github.com/pbek/qt-piwik-tracker.git src/libraries/piwiktracker
rm -rf src/libraries/piwiktracker/.*

git clone https://github.com/qownnotes/QHotkey.git src/libraries/qhotkey
rm -rf src/libraries/qhotkey/.*

git clone https://github.com/pbek/qkeysequencewidget src/libraries/qkeysequencewidget
rm -rf src/libraries/qkeysequencewidget/.*

git clone https://github.com/pbek/qmarkdowntextedit.git src/libraries/qmarkdowntextedit
rm -rf src/libraries/qmarkdowntextedit/.*

git clone https://github.com/pbek/qtcsv.git src/libraries/qtcsv
rm -rf src/libraries/qtcsv/.*

git clone https://github.com/frankosterfeld/qtkeychain.git src/libraries/qtkeychain
rm -rf src/libraries/qtkeychain/.*

git clone https://github.com/pbek/Qt-Toolbar-Editor.git src/libraries/qttoolbareditor
rm -rf src/libraries/qttoolbareditor/.*
